import { useEffect, useRef } from 'react';
import { Canvas as WaveformCanvas } from './Canvas';
import { CanvasLogicalWidth, CanvasLogicalHeight } from '../Waveform';

type Props = {
  peaks: number[][] | null;
  style: React.CSSProperties;
};

export const Waveform: React.FC<Props> = (props: Props) => {
  const hudCanvasRef = useRef<HTMLCanvasElement>(null);

  // handlers

  const handleMouseDown = () => {
    console.log('mousedown');
  };

  // render component

  const canvasStyles = {
    width: '100%',
    height: '100px',
    margin: '0 auto',
    display: 'block',
  } as React.CSSProperties;

  const hudCanvasStyles = {
    width: '100%',
    height: '100%',
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    zIndex: 1,
  } as React.CSSProperties;

  return (
    <>
      <div style={props.style}>
        <WaveformCanvas
          peaks={props.peaks}
          fillStyle="grey"
          strokeStyle="black"
          style={canvasStyles}
        ></WaveformCanvas>
        <canvas
          ref={hudCanvasRef}
          style={hudCanvasStyles}
          width={CanvasLogicalWidth}
          height={CanvasLogicalHeight}
          onMouseDown={handleMouseDown}
        ></canvas>
      </div>
    </>
  );
};
